@@ -1,7 +1,7 @@
 __title__ = 'evernote2'
 __description__ = 'another Evernote SDK for Python'
-__url__ = 'https://github.com/JackonYang/evernote-sdk-python'
-__version__ = '0.0.1'
+__url__ = 'https://github.com/JackonYang/evernote2'
+__version__ = '1.0.0'
 # __build__ = 0x022500
 __author__ = 'Jackon Yang'
 __author_email__ = 'i@jackon.me'
